pathvalidate

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package pathvalidate holds shared relative-path rules for Git and object-store export paths.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RejectTraversal

func RejectTraversal(path string) error

RejectTraversal returns an error when path is absolute or contains parent traversal.

func ValidateRelativeObjectPath

func ValidateRelativeObjectPath(objectPath string) (string, error)

ValidateRelativeObjectPath normalizes and rejects absolute paths, traversal, and null bytes.

Types

This section is empty.

Jump to